@@ -6,4 +6,4 @@ suite, such as the SMQueue service, SIPAuthServe, OpenBTS and NodeManager
 itself.
 """
 
-from .components import OpenBTS
+from .components import OpenBTS, SIPAuthServe, SMQueue
